@@ -138,7 +138,8 @@ sub submit_jobs {
     my ( $exitcode, $stdout, $stderr ) =
       $self->submit_to_scheduler(
         $self->submit_command . " " . $self->slurmfile );
-    sleep(5);
+
+    sleep(3);
 
     if ( $exitcode != 0 ) {
         $self->log->fatal("Job was not submitted successfully");
@@ -171,15 +172,30 @@ sub update_job_deps {
 
     return unless $self->has_array_deps;
 
-    my $array_deps_file = File::Spec->catdir($self->logdir , 'array_deps.txt');
+    my $array_deps_file = File::Spec->catdir( $self->logdir, 'array_deps.tsv' );
+    my $array_log_file  = File::Spec->catdir( $self->logdir, 'array_deps.log' );
 
     while ( my ( $current_task, $v ) = each %{ $self->array_deps } ) {
         my $dep_tasks = join( ':', @{$v} );
         my $cmd =
-          "scontrol update job=$current_task -W depend=afterok:$dep_tasks";
+          "scontrol update job=$current_task depend=afterok:$dep_tasks";
 
-        $self->submit_to_scheduler($cmd);
-        write_file($array_deps_file, { append => 1 }, $current_task."\t".join(',', @{$v}));
+        my ( $exitcode, $stdout, $stderr ) = $self->submit_to_scheduler($cmd);
+        write_file(
+            $array_deps_file,
+            { append => 1 },
+            $current_task . "\t" . $dep_tasks . "\n"
+        );
+
+        my $info =
+            "Task Deps:\t"
+          . $current_task . "\t"
+          . $dep_tasks . "\n"
+          . "ExitCode: $exitcode\n";
+        $info .= "Stderr: $stderr\n" if $stderr;
+        $info .= "Stdout: $stdout\n" if $stdout;
+
+        write_file( $array_log_file, {append => 1}, $info );
     }
 }
 
